summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--CHANGELOG1
-rw-r--r--CMakeLists.txt46
-rw-r--r--README.md2
-rw-r--r--samples/sgemm.cpp (renamed from samples/sgemm.cc)0
-rw-r--r--scripts/generator/generator.py20
-rw-r--r--src/cache.cpp (renamed from src/cache.cc)0
-rw-r--r--src/clblast.cpp (renamed from src/clblast.cc)0
-rw-r--r--src/clblast_c.cpp (renamed from src/clblast_c.cc)0
-rw-r--r--src/database/database.cpp (renamed from src/database/database.cc)0
-rw-r--r--src/routine.cpp (renamed from src/routine.cc)0
-rw-r--r--src/routines/common.cpp (renamed from src/routines/common.cc)0
-rw-r--r--src/routines/level1/xamax.cpp (renamed from src/routines/level1/xamax.cc)0
-rw-r--r--src/routines/level1/xasum.cpp (renamed from src/routines/level1/xasum.cc)0
-rw-r--r--src/routines/level1/xaxpy.cpp (renamed from src/routines/level1/xaxpy.cc)0
-rw-r--r--src/routines/level1/xcopy.cpp (renamed from src/routines/level1/xcopy.cc)0
-rw-r--r--src/routines/level1/xdot.cpp (renamed from src/routines/level1/xdot.cc)0
-rw-r--r--src/routines/level1/xdotc.cpp (renamed from src/routines/level1/xdotc.cc)0
-rw-r--r--src/routines/level1/xdotu.cpp (renamed from src/routines/level1/xdotu.cc)0
-rw-r--r--src/routines/level1/xnrm2.cpp (renamed from src/routines/level1/xnrm2.cc)0
-rw-r--r--src/routines/level1/xscal.cpp (renamed from src/routines/level1/xscal.cc)0
-rw-r--r--src/routines/level1/xswap.cpp (renamed from src/routines/level1/xswap.cc)0
-rw-r--r--src/routines/level2/xgbmv.cpp (renamed from src/routines/level2/xgbmv.cc)0
-rw-r--r--src/routines/level2/xgemv.cpp (renamed from src/routines/level2/xgemv.cc)0
-rw-r--r--src/routines/level2/xger.cpp (renamed from src/routines/level2/xger.cc)0
-rw-r--r--src/routines/level2/xgerc.cpp (renamed from src/routines/level2/xgerc.cc)0
-rw-r--r--src/routines/level2/xgeru.cpp (renamed from src/routines/level2/xgeru.cc)0
-rw-r--r--src/routines/level2/xhbmv.cpp (renamed from src/routines/level2/xhbmv.cc)0
-rw-r--r--src/routines/level2/xhemv.cpp (renamed from src/routines/level2/xhemv.cc)0
-rw-r--r--src/routines/level2/xher.cpp (renamed from src/routines/level2/xher.cc)0
-rw-r--r--src/routines/level2/xher2.cpp (renamed from src/routines/level2/xher2.cc)0
-rw-r--r--src/routines/level2/xhpmv.cpp (renamed from src/routines/level2/xhpmv.cc)0
-rw-r--r--src/routines/level2/xhpr.cpp (renamed from src/routines/level2/xhpr.cc)0
-rw-r--r--src/routines/level2/xhpr2.cpp (renamed from src/routines/level2/xhpr2.cc)0
-rw-r--r--src/routines/level2/xsbmv.cpp (renamed from src/routines/level2/xsbmv.cc)0
-rw-r--r--src/routines/level2/xspmv.cpp (renamed from src/routines/level2/xspmv.cc)0
-rw-r--r--src/routines/level2/xspr.cpp (renamed from src/routines/level2/xspr.cc)0
-rw-r--r--src/routines/level2/xspr2.cpp (renamed from src/routines/level2/xspr2.cc)0
-rw-r--r--src/routines/level2/xsymv.cpp (renamed from src/routines/level2/xsymv.cc)0
-rw-r--r--src/routines/level2/xsyr.cpp (renamed from src/routines/level2/xsyr.cc)0
-rw-r--r--src/routines/level2/xsyr2.cpp (renamed from src/routines/level2/xsyr2.cc)0
-rw-r--r--src/routines/level2/xtbmv.cpp (renamed from src/routines/level2/xtbmv.cc)0
-rw-r--r--src/routines/level2/xtpmv.cpp (renamed from src/routines/level2/xtpmv.cc)0
-rw-r--r--src/routines/level2/xtrmv.cpp (renamed from src/routines/level2/xtrmv.cc)0
-rw-r--r--src/routines/level3/xgemm.cpp (renamed from src/routines/level3/xgemm.cc)0
-rw-r--r--src/routines/level3/xhemm.cpp (renamed from src/routines/level3/xhemm.cc)0
-rw-r--r--src/routines/level3/xher2k.cpp (renamed from src/routines/level3/xher2k.cc)0
-rw-r--r--src/routines/level3/xherk.cpp (renamed from src/routines/level3/xherk.cc)0
-rw-r--r--src/routines/level3/xsymm.cpp (renamed from src/routines/level3/xsymm.cc)0
-rw-r--r--src/routines/level3/xsyr2k.cpp (renamed from src/routines/level3/xsyr2k.cc)0
-rw-r--r--src/routines/level3/xsyrk.cpp (renamed from src/routines/level3/xsyrk.cc)0
-rw-r--r--src/routines/level3/xtrmm.cpp (renamed from src/routines/level3/xtrmm.cc)0
-rw-r--r--src/routines/levelx/xomatcopy.cpp (renamed from src/routines/levelx/xomatcopy.cc)0
-rw-r--r--src/tuning/kernels/copy_fast.cpp (renamed from src/tuning/kernels/copy_fast.cc)0
-rw-r--r--src/tuning/kernels/copy_pad.cpp (renamed from src/tuning/kernels/copy_pad.cc)0
-rw-r--r--src/tuning/kernels/transpose_fast.cpp (renamed from src/tuning/kernels/transpose_fast.cc)0
-rw-r--r--src/tuning/kernels/transpose_pad.cpp (renamed from src/tuning/kernels/transpose_pad.cc)0
-rw-r--r--src/tuning/kernels/xaxpy.cpp (renamed from src/tuning/kernels/xaxpy.cc)0
-rw-r--r--src/tuning/kernels/xdot.cpp (renamed from src/tuning/kernels/xdot.cc)0
-rw-r--r--src/tuning/kernels/xgemm.cpp (renamed from src/tuning/kernels/xgemm.cc)0
-rw-r--r--src/tuning/kernels/xgemv.cpp (renamed from src/tuning/kernels/xgemv.cc)0
-rw-r--r--src/tuning/kernels/xger.cpp (renamed from src/tuning/kernels/xger.cc)0
-rw-r--r--src/utilities.cpp (renamed from src/utilities.cc)0
-rw-r--r--test/correctness/routines/level1/xamax.cpp (renamed from test/correctness/routines/level1/xamax.cc)0
-rw-r--r--test/correctness/routines/level1/xasum.cpp (renamed from test/correctness/routines/level1/xasum.cc)0
-rw-r--r--test/correctness/routines/level1/xaxpy.cpp (renamed from test/correctness/routines/level1/xaxpy.cc)0
-rw-r--r--test/correctness/routines/level1/xcopy.cpp (renamed from test/correctness/routines/level1/xcopy.cc)0
-rw-r--r--test/correctness/routines/level1/xdot.cpp (renamed from test/correctness/routines/level1/xdot.cc)0
-rw-r--r--test/correctness/routines/level1/xdotc.cpp (renamed from test/correctness/routines/level1/xdotc.cc)0
-rw-r--r--test/correctness/routines/level1/xdotu.cpp (renamed from test/correctness/routines/level1/xdotu.cc)0
-rw-r--r--test/correctness/routines/level1/xnrm2.cpp (renamed from test/correctness/routines/level1/xnrm2.cc)0
-rw-r--r--test/correctness/routines/level1/xrot.cpp (renamed from test/correctness/routines/level1/xrot.cc)0
-rw-r--r--test/correctness/routines/level1/xrotg.cpp (renamed from test/correctness/routines/level1/xrotg.cc)0
-rw-r--r--test/correctness/routines/level1/xrotm.cpp (renamed from test/correctness/routines/level1/xrotm.cc)0
-rw-r--r--test/correctness/routines/level1/xrotmg.cpp (renamed from test/correctness/routines/level1/xrotmg.cc)0
-rw-r--r--test/correctness/routines/level1/xscal.cpp (renamed from test/correctness/routines/level1/xscal.cc)0
-rw-r--r--test/correctness/routines/level1/xswap.cpp (renamed from test/correctness/routines/level1/xswap.cc)0
-rw-r--r--test/correctness/routines/level2/xgbmv.cpp (renamed from test/correctness/routines/level2/xgbmv.cc)0
-rw-r--r--test/correctness/routines/level2/xgemv.cpp (renamed from test/correctness/routines/level2/xgemv.cc)0
-rw-r--r--test/correctness/routines/level2/xger.cpp (renamed from test/correctness/routines/level2/xger.cc)0
-rw-r--r--test/correctness/routines/level2/xgerc.cpp (renamed from test/correctness/routines/level2/xgerc.cc)0
-rw-r--r--test/correctness/routines/level2/xgeru.cpp (renamed from test/correctness/routines/level2/xgeru.cc)0
-rw-r--r--test/correctness/routines/level2/xhbmv.cpp (renamed from test/correctness/routines/level2/xhbmv.cc)0
-rw-r--r--test/correctness/routines/level2/xhemv.cpp (renamed from test/correctness/routines/level2/xhemv.cc)0
-rw-r--r--test/correctness/routines/level2/xher.cpp (renamed from test/correctness/routines/level2/xher.cc)0
-rw-r--r--test/correctness/routines/level2/xher2.cpp (renamed from test/correctness/routines/level2/xher2.cc)0
-rw-r--r--test/correctness/routines/level2/xhpmv.cpp (renamed from test/correctness/routines/level2/xhpmv.cc)0
-rw-r--r--test/correctness/routines/level2/xhpr.cpp (renamed from test/correctness/routines/level2/xhpr.cc)0
-rw-r--r--test/correctness/routines/level2/xhpr2.cpp (renamed from test/correctness/routines/level2/xhpr2.cc)0
-rw-r--r--test/correctness/routines/level2/xsbmv.cpp (renamed from test/correctness/routines/level2/xsbmv.cc)0
-rw-r--r--test/correctness/routines/level2/xspmv.cpp (renamed from test/correctness/routines/level2/xspmv.cc)0
-rw-r--r--test/correctness/routines/level2/xspr.cpp (renamed from test/correctness/routines/level2/xspr.cc)0
-rw-r--r--test/correctness/routines/level2/xspr2.cpp (renamed from test/correctness/routines/level2/xspr2.cc)0
-rw-r--r--test/correctness/routines/level2/xsymv.cpp (renamed from test/correctness/routines/level2/xsymv.cc)0
-rw-r--r--test/correctness/routines/level2/xsyr.cpp (renamed from test/correctness/routines/level2/xsyr.cc)0
-rw-r--r--test/correctness/routines/level2/xsyr2.cpp (renamed from test/correctness/routines/level2/xsyr2.cc)0
-rw-r--r--test/correctness/routines/level2/xtbmv.cpp (renamed from test/correctness/routines/level2/xtbmv.cc)0
-rw-r--r--test/correctness/routines/level2/xtbsv.cpp (renamed from test/correctness/routines/level2/xtbsv.cc)0
-rw-r--r--test/correctness/routines/level2/xtpmv.cpp (renamed from test/correctness/routines/level2/xtpmv.cc)0
-rw-r--r--test/correctness/routines/level2/xtpsv.cpp (renamed from test/correctness/routines/level2/xtpsv.cc)0
-rw-r--r--test/correctness/routines/level2/xtrmv.cpp (renamed from test/correctness/routines/level2/xtrmv.cc)0
-rw-r--r--test/correctness/routines/level2/xtrsv.cpp (renamed from test/correctness/routines/level2/xtrsv.cc)0
-rw-r--r--test/correctness/routines/level3/xgemm.cpp (renamed from test/correctness/routines/level3/xgemm.cc)0
-rw-r--r--test/correctness/routines/level3/xhemm.cpp (renamed from test/correctness/routines/level3/xhemm.cc)0
-rw-r--r--test/correctness/routines/level3/xher2k.cpp (renamed from test/correctness/routines/level3/xher2k.cc)0
-rw-r--r--test/correctness/routines/level3/xherk.cpp (renamed from test/correctness/routines/level3/xherk.cc)0
-rw-r--r--test/correctness/routines/level3/xsymm.cpp (renamed from test/correctness/routines/level3/xsymm.cc)0
-rw-r--r--test/correctness/routines/level3/xsyr2k.cpp (renamed from test/correctness/routines/level3/xsyr2k.cc)0
-rw-r--r--test/correctness/routines/level3/xsyrk.cpp (renamed from test/correctness/routines/level3/xsyrk.cc)0
-rw-r--r--test/correctness/routines/level3/xtrmm.cpp (renamed from test/correctness/routines/level3/xtrmm.cc)0
-rw-r--r--test/correctness/routines/level3/xtrsm.cpp (renamed from test/correctness/routines/level3/xtrsm.cc)0
-rw-r--r--test/correctness/routines/levelx/xomatcopy.cpp (renamed from test/correctness/routines/levelx/xomatcopy.cc)0
-rw-r--r--test/correctness/testblas.cpp (renamed from test/correctness/testblas.cc)0
-rw-r--r--test/correctness/tester.cpp (renamed from test/correctness/tester.cc)0
-rw-r--r--test/performance/client.cpp (renamed from test/performance/client.cc)0
-rw-r--r--test/performance/routines/level1/xamax.cpp (renamed from test/performance/routines/level1/xamax.cc)0
-rw-r--r--test/performance/routines/level1/xasum.cpp (renamed from test/performance/routines/level1/xasum.cc)0
-rw-r--r--test/performance/routines/level1/xaxpy.cpp (renamed from test/performance/routines/level1/xaxpy.cc)0
-rw-r--r--test/performance/routines/level1/xcopy.cpp (renamed from test/performance/routines/level1/xcopy.cc)0
-rw-r--r--test/performance/routines/level1/xdot.cpp (renamed from test/performance/routines/level1/xdot.cc)0
-rw-r--r--test/performance/routines/level1/xdotc.cpp (renamed from test/performance/routines/level1/xdotc.cc)0
-rw-r--r--test/performance/routines/level1/xdotu.cpp (renamed from test/performance/routines/level1/xdotu.cc)0
-rw-r--r--test/performance/routines/level1/xnrm2.cpp (renamed from test/performance/routines/level1/xnrm2.cc)0
-rw-r--r--test/performance/routines/level1/xrot.cpp (renamed from test/performance/routines/level1/xrot.cc)0
-rw-r--r--test/performance/routines/level1/xrotg.cpp (renamed from test/performance/routines/level1/xrotg.cc)0
-rw-r--r--test/performance/routines/level1/xrotm.cpp (renamed from test/performance/routines/level1/xrotm.cc)0
-rw-r--r--test/performance/routines/level1/xrotmg.cpp (renamed from test/performance/routines/level1/xrotmg.cc)0
-rw-r--r--test/performance/routines/level1/xscal.cpp (renamed from test/performance/routines/level1/xscal.cc)0
-rw-r--r--test/performance/routines/level1/xswap.cpp (renamed from test/performance/routines/level1/xswap.cc)0
-rw-r--r--test/performance/routines/level2/xgbmv.cpp (renamed from test/performance/routines/level2/xgbmv.cc)0
-rw-r--r--test/performance/routines/level2/xgemv.cpp (renamed from test/performance/routines/level2/xgemv.cc)0
-rw-r--r--test/performance/routines/level2/xger.cpp (renamed from test/performance/routines/level2/xger.cc)0
-rw-r--r--test/performance/routines/level2/xgerc.cpp (renamed from test/performance/routines/level2/xgerc.cc)0
-rw-r--r--test/performance/routines/level2/xgeru.cpp (renamed from test/performance/routines/level2/xgeru.cc)0
-rw-r--r--test/performance/routines/level2/xhbmv.cpp (renamed from test/performance/routines/level2/xhbmv.cc)0
-rw-r--r--test/performance/routines/level2/xhemv.cpp (renamed from test/performance/routines/level2/xhemv.cc)0
-rw-r--r--test/performance/routines/level2/xher.cpp (renamed from test/performance/routines/level2/xher.cc)0
-rw-r--r--test/performance/routines/level2/xher2.cpp (renamed from test/performance/routines/level2/xher2.cc)0
-rw-r--r--test/performance/routines/level2/xhpmv.cpp (renamed from test/performance/routines/level2/xhpmv.cc)0
-rw-r--r--test/performance/routines/level2/xhpr.cpp (renamed from test/performance/routines/level2/xhpr.cc)0
-rw-r--r--test/performance/routines/level2/xhpr2.cpp (renamed from test/performance/routines/level2/xhpr2.cc)0
-rw-r--r--test/performance/routines/level2/xsbmv.cpp (renamed from test/performance/routines/level2/xsbmv.cc)0
-rw-r--r--test/performance/routines/level2/xspmv.cpp (renamed from test/performance/routines/level2/xspmv.cc)0
-rw-r--r--test/performance/routines/level2/xspr.cpp (renamed from test/performance/routines/level2/xspr.cc)0
-rw-r--r--test/performance/routines/level2/xspr2.cpp (renamed from test/performance/routines/level2/xspr2.cc)0
-rw-r--r--test/performance/routines/level2/xsymv.cpp (renamed from test/performance/routines/level2/xsymv.cc)0
-rw-r--r--test/performance/routines/level2/xsyr.cpp (renamed from test/performance/routines/level2/xsyr.cc)0
-rw-r--r--test/performance/routines/level2/xsyr2.cpp (renamed from test/performance/routines/level2/xsyr2.cc)0
-rw-r--r--test/performance/routines/level2/xtbmv.cpp (renamed from test/performance/routines/level2/xtbmv.cc)0
-rw-r--r--test/performance/routines/level2/xtbsv.cpp (renamed from test/performance/routines/level2/xtbsv.cc)0
-rw-r--r--test/performance/routines/level2/xtpmv.cpp (renamed from test/performance/routines/level2/xtpmv.cc)0
-rw-r--r--test/performance/routines/level2/xtpsv.cpp (renamed from test/performance/routines/level2/xtpsv.cc)0
-rw-r--r--test/performance/routines/level2/xtrmv.cpp (renamed from test/performance/routines/level2/xtrmv.cc)0
-rw-r--r--test/performance/routines/level2/xtrsv.cpp (renamed from test/performance/routines/level2/xtrsv.cc)0
-rw-r--r--test/performance/routines/level3/xgemm.cpp (renamed from test/performance/routines/level3/xgemm.cc)0
-rw-r--r--test/performance/routines/level3/xhemm.cpp (renamed from test/performance/routines/level3/xhemm.cc)0
-rw-r--r--test/performance/routines/level3/xher2k.cpp (renamed from test/performance/routines/level3/xher2k.cc)0
-rw-r--r--test/performance/routines/level3/xherk.cpp (renamed from test/performance/routines/level3/xherk.cc)0
-rw-r--r--test/performance/routines/level3/xsymm.cpp (renamed from test/performance/routines/level3/xsymm.cc)0
-rw-r--r--test/performance/routines/level3/xsyr2k.cpp (renamed from test/performance/routines/level3/xsyr2k.cc)0
-rw-r--r--test/performance/routines/level3/xsyrk.cpp (renamed from test/performance/routines/level3/xsyrk.cc)0
-rw-r--r--test/performance/routines/level3/xtrmm.cpp (renamed from test/performance/routines/level3/xtrmm.cc)0
-rw-r--r--test/performance/routines/level3/xtrsm.cpp (renamed from test/performance/routines/level3/xtrsm.cc)0
-rw-r--r--test/performance/routines/levelx/xomatcopy.cpp (renamed from test/performance/routines/levelx/xomatcopy.cc)0
163 files changed, 35 insertions, 34 deletions
diff --git a/CHANGELOG b/CHANGELOG
index e9063b91..fd5b3610 100644
--- a/CHANGELOG
+++ b/CHANGELOG
@@ -4,6 +4,7 @@ Development version (next release)
- Made it possible to compile the performance tests (clients) separately from the correctness tests
- Made a reference BLAS and head-to-head performance comparison optional in the clients
- Increased the verbosity of the "-verbose" option in the correctness tests
+- Refactored the host code for better compilation times and fewer lines of code
- Improved the API documentation
- Various minor fixes and enhancements
- Added tuned parameters for various devices (see README)
diff --git a/CMakeLists.txt b/CMakeLists.txt
index 5ca56bd7..0df2b3bd 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -141,25 +141,25 @@ set(PRECISIONS 32 64 3232 6464)
# Gathers all source-files
set(SOURCES
- src/database/database.cc
- src/routines/common.cc
- src/cache.cc
- src/clblast.cc
- src/clblast_c.cc
- src/routine.cc
- src/utilities.cc
+ src/database/database.cpp
+ src/routines/common.cpp
+ src/cache.cpp
+ src/clblast.cpp
+ src/clblast_c.cpp
+ src/routine.cpp
+ src/utilities.cpp
)
foreach(ROUTINE ${LEVEL1_ROUTINES})
- set(SOURCES ${SOURCES} src/routines/level1/${ROUTINE}.cc)
+ set(SOURCES ${SOURCES} src/routines/level1/${ROUTINE}.cpp)
endforeach()
foreach(ROUTINE ${LEVEL2_ROUTINES})
- set(SOURCES ${SOURCES} src/routines/level2/${ROUTINE}.cc)
+ set(SOURCES ${SOURCES} src/routines/level2/${ROUTINE}.cpp)
endforeach()
foreach(ROUTINE ${LEVEL3_ROUTINES})
- set(SOURCES ${SOURCES} src/routines/level3/${ROUTINE}.cc)
+ set(SOURCES ${SOURCES} src/routines/level3/${ROUTINE}.cpp)
endforeach()
foreach(ROUTINE ${LEVELX_ROUTINES})
- set(SOURCES ${SOURCES} src/routines/levelx/${ROUTINE}.cc)
+ set(SOURCES ${SOURCES} src/routines/levelx/${ROUTINE}.cpp)
endforeach()
# Creates and links the library
@@ -193,7 +193,7 @@ if(SAMPLES)
# Adds sample programs (C++)
foreach(SAMPLE ${SAMPLE_PROGRAMS_CPP})
- add_executable(clblast_sample_${SAMPLE} samples/${SAMPLE}.cc)
+ add_executable(clblast_sample_${SAMPLE} samples/${SAMPLE}.cpp)
target_link_libraries(clblast_sample_${SAMPLE} clblast ${OPENCL_LIBRARIES})
install(TARGETS clblast_sample_${SAMPLE} DESTINATION bin)
endforeach()
@@ -218,7 +218,7 @@ if(TUNERS)
# Adds tuning executables
foreach(KERNEL ${KERNELS})
- add_executable(clblast_tuner_${KERNEL} src/tuning/kernels/${KERNEL}.cc)
+ add_executable(clblast_tuner_${KERNEL} src/tuning/kernels/${KERNEL}.cpp)
target_link_libraries(clblast_tuner_${KERNEL} clblast ${CLTUNE_LIBRARIES} ${OPENCL_LIBRARIES})
install(TARGETS clblast_tuner_${KERNEL} DESTINATION bin)
endforeach()
@@ -275,24 +275,24 @@ endif()
if(CLIENTS)
# Creates the common performance-tests objects (requires CMake 2.8.8)
- add_library(test_performance_common OBJECT test/performance/client.cc)
+ add_library(test_performance_common OBJECT test/performance/client.cpp)
# Compiles the performance-tests
foreach(ROUTINE ${LEVEL1_ROUTINES})
add_executable(clblast_client_${ROUTINE} $<TARGET_OBJECTS:test_performance_common>
- test/performance/routines/level1/${ROUTINE}.cc)
+ test/performance/routines/level1/${ROUTINE}.cpp)
endforeach()
foreach(ROUTINE ${LEVEL2_ROUTINES})
add_executable(clblast_client_${ROUTINE} $<TARGET_OBJECTS:test_performance_common>
- test/performance/routines/level2/${ROUTINE}.cc)
+ test/performance/routines/level2/${ROUTINE}.cpp)
endforeach()
foreach(ROUTINE ${LEVEL3_ROUTINES})
add_executable(clblast_client_${ROUTINE} $<TARGET_OBJECTS:test_performance_common>
- test/performance/routines/level3/${ROUTINE}.cc)
+ test/performance/routines/level3/${ROUTINE}.cpp)
endforeach()
foreach(ROUTINE ${LEVELX_ROUTINES})
add_executable(clblast_client_${ROUTINE} $<TARGET_OBJECTS:test_performance_common>
- test/performance/routines/levelx/${ROUTINE}.cc)
+ test/performance/routines/levelx/${ROUTINE}.cpp)
endforeach()
foreach(ROUTINE ${ROUTINES})
target_link_libraries(clblast_client_${ROUTINE} clblast ${REF_LIBRARIES} ${OPENCL_LIBRARIES})
@@ -310,24 +310,24 @@ if(TESTS)
# Creates the common correctness-tests objects (requires CMake 2.8.8)
add_library(test_correctness_common OBJECT
- test/correctness/tester.cc test/correctness/testblas.cc)
+ test/correctness/tester.cpp test/correctness/testblas.cpp)
# Compiles the correctness-tests
foreach(ROUTINE ${LEVEL1_ROUTINES})
add_executable(clblast_test_${ROUTINE} $<TARGET_OBJECTS:test_correctness_common>
- test/correctness/routines/level1/${ROUTINE}.cc)
+ test/correctness/routines/level1/${ROUTINE}.cpp)
endforeach()
foreach(ROUTINE ${LEVEL2_ROUTINES})
add_executable(clblast_test_${ROUTINE} $<TARGET_OBJECTS:test_correctness_common>
- test/correctness/routines/level2/${ROUTINE}.cc)
+ test/correctness/routines/level2/${ROUTINE}.cpp)
endforeach()
foreach(ROUTINE ${LEVEL3_ROUTINES})
add_executable(clblast_test_${ROUTINE} $<TARGET_OBJECTS:test_correctness_common>
- test/correctness/routines/level3/${ROUTINE}.cc)
+ test/correctness/routines/level3/${ROUTINE}.cpp)
endforeach()
foreach(ROUTINE ${LEVELX_ROUTINES})
add_executable(clblast_test_${ROUTINE} $<TARGET_OBJECTS:test_correctness_common>
- test/correctness/routines/levelx/${ROUTINE}.cc)
+ test/correctness/routines/levelx/${ROUTINE}.cpp)
endforeach()
foreach(ROUTINE ${ROUTINES})
target_link_libraries(clblast_test_${ROUTINE} clblast ${REF_LIBRARIES} ${OPENCL_LIBRARIES})
diff --git a/README.md b/README.md
index 26dfb149..5d2c0c9e 100644
--- a/README.md
+++ b/README.md
@@ -136,7 +136,7 @@ Note that CLBlast's tuners are based on the CLTune auto-tuning library, which ha
Compiling with `-DTUNERS=ON` will generate a number of tuners, each named `clblast_tuner_xxxxx`, in which `xxxxx` corresponds to a `.opencl` kernel file as found in `src/kernels`. These kernels corresponds to routines (e.g. `xgemm`) or to common pre-processing or post-processing kernels (`copy` and `transpose`). Running such a tuner will test a number of parameter-value combinations on your device and report which one gave the best performance. Running `make alltuners` runs all tuners for all precisions in one go. You can set the default device and platform for `alltuners` by setting the `DEFAULT_DEVICE` and `DEFAULT_PLATFORM` environmental variables before running CMake.
-The tuners output a JSON-file with the results. The best results need to be added to `include/internal/database/xxxxx.h` in the appropriate section. However, this can be done automatically based on the JSON-data using a Python script in `scripts/database/database.py`. If you want the found parameters to be included in future releases of CLBlast, please attach the JSON files to the corresponding issue on GitHub or [email the main author](http://www.cedricnugteren.nl).
+The tuners output a JSON-file with the results. The best results need to be added to `include/internal/database/xxxxx.hpp` in the appropriate section. However, this can be done automatically based on the JSON-data using a Python script in `scripts/database/database.py`. If you want the found parameters to be included in future releases of CLBlast, please attach the JSON files to the corresponding issue on GitHub or [email the main author](http://www.cedricnugteren.nl).
In summary, tuning the entire library for your device can be done as follows (starting from the root of the CLBlast folder):
diff --git a/samples/sgemm.cc b/samples/sgemm.cpp
index 5fe7490a..5fe7490a 100644
--- a/samples/sgemm.cc
+++ b/samples/sgemm.cpp
diff --git a/src/cache.cc b/src/cache.cpp
index cd9055d0..cd9055d0 100644
--- a/src/cache.cc
+++ b/src/cache.cpp
diff --git a/src/clblast.cc b/src/clblast.cpp
index 88d60772..88d60772 100644
--- a/src/clblast.cc
+++ b/src/clblast.cpp
diff --git a/src/clblast_c.cc b/src/clblast_c.cpp
index 9ea2c884..9ea2c884 100644
--- a/src/clblast_c.cc
+++ b/src/clblast_c.cpp
diff --git a/src/database/database.cc b/src/database/database.cpp
index 6ec93731..6ec93731 100644
--- a/src/database/database.cc
+++ b/src/database/database.cpp
diff --git a/src/routine.cc b/src/routine.cpp
index d3590896..d3590896 100644
--- a/src/routine.cc
+++ b/src/routine.cpp
diff --git a/src/routines/common.cc b/src/routines/common.cpp
index c378df28..c378df28 100644
--- a/src/routines/common.cc
+++ b/src/routines/common.cpp
diff --git a/src/routines/level1/xamax.cc b/src/routines/level1/xamax.cpp
index 6b6e7f9e..6b6e7f9e 100644
--- a/src/routines/level1/xamax.cc
+++ b/src/routines/level1/xamax.cpp
diff --git a/src/routines/level1/xasum.cc b/src/routines/level1/xasum.cpp
index 0c1ce903..0c1ce903 100644
--- a/src/routines/level1/xasum.cc
+++ b/src/routines/level1/xasum.cpp
diff --git a/src/routines/level1/xaxpy.cc b/src/routines/level1/xaxpy.cpp
index 5b6c9e77..5b6c9e77 100644
--- a/src/routines/level1/xaxpy.cc
+++ b/src/routines/level1/xaxpy.cpp
diff --git a/src/routines/level1/xcopy.cc b/src/routines/level1/xcopy.cpp
index 673ef349..673ef349 100644
--- a/src/routines/level1/xcopy.cc
+++ b/src/routines/level1/xcopy.cpp
diff --git a/src/routines/level1/xdot.cc b/src/routines/level1/xdot.cpp
index bafea157..bafea157 100644
--- a/src/routines/level1/xdot.cc
+++ b/src/routines/level1/xdot.cpp
diff --git a/src/routines/level1/xdotc.cc b/src/routines/level1/xdotc.cpp
index 27cf2bab..27cf2bab 100644
--- a/src/routines/level1/xdotc.cc
+++ b/src/routines/level1/xdotc.cpp
diff --git a/src/routines/level1/xdotu.cc b/src/routines/level1/xdotu.cpp
index 0bce70b7..0bce70b7 100644
--- a/src/routines/level1/xdotu.cc
+++ b/src/routines/level1/xdotu.cpp
diff --git a/src/routines/level1/xnrm2.cc b/src/routines/level1/xnrm2.cpp
index 97615d8b..97615d8b 100644
--- a/src/routines/level1/xnrm2.cc
+++ b/src/routines/level1/xnrm2.cpp
diff --git a/src/routines/level1/xscal.cc b/src/routines/level1/xscal.cpp
index bcc43c3b..bcc43c3b 100644
--- a/src/routines/level1/xscal.cc
+++ b/src/routines/level1/xscal.cpp
diff --git a/src/routines/level1/xswap.cc b/src/routines/level1/xswap.cpp
index 03907cbd..03907cbd 100644
--- a/src/routines/level1/xswap.cc
+++ b/src/routines/level1/xswap.cpp
diff --git a/src/routines/level2/xgbmv.cc b/src/routines/level2/xgbmv.cpp
index ea4f001c..ea4f001c 100644
--- a/src/routines/level2/xgbmv.cc
+++ b/src/routines/level2/xgbmv.cpp
diff --git a/src/routines/level2/xgemv.cc b/src/routines/level2/xgemv.cpp
index 21fb397c..21fb397c 100644
--- a/src/routines/level2/xgemv.cc
+++ b/src/routines/level2/xgemv.cpp
diff --git a/src/routines/level2/xger.cc b/src/routines/level2/xger.cpp
index 353047d2..353047d2 100644
--- a/src/routines/level2/xger.cc
+++ b/src/routines/level2/xger.cpp
diff --git a/src/routines/level2/xgerc.cc b/src/routines/level2/xgerc.cpp
index d9feda97..d9feda97 100644
--- a/src/routines/level2/xgerc.cc
+++ b/src/routines/level2/xgerc.cpp
diff --git a/src/routines/level2/xgeru.cc b/src/routines/level2/xgeru.cpp
index da9e91c2..da9e91c2 100644
--- a/src/routines/level2/xgeru.cc
+++ b/src/routines/level2/xgeru.cpp
diff --git a/src/routines/level2/xhbmv.cc b/src/routines/level2/xhbmv.cpp
index f6c0e3c4..f6c0e3c4 100644
--- a/src/routines/level2/xhbmv.cc
+++ b/src/routines/level2/xhbmv.cpp
diff --git a/src/routines/level2/xhemv.cc b/src/routines/level2/xhemv.cpp
index 2cbcf7b4..2cbcf7b4 100644
--- a/src/routines/level2/xhemv.cc
+++ b/src/routines/level2/xhemv.cpp
diff --git a/src/routines/level2/xher.cc b/src/routines/level2/xher.cpp
index ed8ba9e9..ed8ba9e9 100644
--- a/src/routines/level2/xher.cc
+++ b/src/routines/level2/xher.cpp
diff --git a/src/routines/level2/xher2.cc b/src/routines/level2/xher2.cpp
index 50572cea..50572cea 100644
--- a/src/routines/level2/xher2.cc
+++ b/src/routines/level2/xher2.cpp
diff --git a/src/routines/level2/xhpmv.cc b/src/routines/level2/xhpmv.cpp
index e6f82b34..e6f82b34 100644
--- a/src/routines/level2/xhpmv.cc
+++ b/src/routines/level2/xhpmv.cpp
diff --git a/src/routines/level2/xhpr.cc b/src/routines/level2/xhpr.cpp
index 225ebfe5..225ebfe5 100644
--- a/src/routines/level2/xhpr.cc
+++ b/src/routines/level2/xhpr.cpp
diff --git a/src/routines/level2/xhpr2.cc b/src/routines/level2/xhpr2.cpp
index 85f9d3f9..85f9d3f9 100644
--- a/src/routines/level2/xhpr2.cc
+++ b/src/routines/level2/xhpr2.cpp
diff --git a/src/routines/level2/xsbmv.cc b/src/routines/level2/xsbmv.cpp
index 28730899..28730899 100644
--- a/src/routines/level2/xsbmv.cc
+++ b/src/routines/level2/xsbmv.cpp
diff --git a/src/routines/level2/xspmv.cc b/src/routines/level2/xspmv.cpp
index f6651012..f6651012 100644
--- a/src/routines/level2/xspmv.cc
+++ b/src/routines/level2/xspmv.cpp
diff --git a/src/routines/level2/xspr.cc b/src/routines/level2/xspr.cpp
index a75fe9c3..a75fe9c3 100644
--- a/src/routines/level2/xspr.cc
+++ b/src/routines/level2/xspr.cpp
diff --git a/src/routines/level2/xspr2.cc b/src/routines/level2/xspr2.cpp
index c39a2eb4..c39a2eb4 100644
--- a/src/routines/level2/xspr2.cc
+++ b/src/routines/level2/xspr2.cpp
diff --git a/src/routines/level2/xsymv.cc b/src/routines/level2/xsymv.cpp
index 648d2a3e..648d2a3e 100644
--- a/src/routines/level2/xsymv.cc
+++ b/src/routines/level2/xsymv.cpp
diff --git a/src/routines/level2/xsyr.cc b/src/routines/level2/xsyr.cpp
index 758d8f8f..758d8f8f 100644
--- a/src/routines/level2/xsyr.cc
+++ b/src/routines/level2/xsyr.cpp
diff --git a/src/routines/level2/xsyr2.cc b/src/routines/level2/xsyr2.cpp
index 6f43b219..6f43b219 100644
--- a/src/routines/level2/xsyr2.cc
+++ b/src/routines/level2/xsyr2.cpp
diff --git a/src/routines/level2/xtbmv.cc b/src/routines/level2/xtbmv.cpp
index e315c544..e315c544 100644
--- a/src/routines/level2/xtbmv.cc
+++ b/src/routines/level2/xtbmv.cpp
diff --git a/src/routines/level2/xtpmv.cc b/src/routines/level2/xtpmv.cpp
index 46811089..46811089 100644
--- a/src/routines/level2/xtpmv.cc
+++ b/src/routines/level2/xtpmv.cpp
diff --git a/src/routines/level2/xtrmv.cc b/src/routines/level2/xtrmv.cpp
index d2f24252..d2f24252 100644
--- a/src/routines/level2/xtrmv.cc
+++ b/src/routines/level2/xtrmv.cpp
diff --git a/src/routines/level3/xgemm.cc b/src/routines/level3/xgemm.cpp
index 9ea5559c..9ea5559c 100644
--- a/src/routines/level3/xgemm.cc
+++ b/src/routines/level3/xgemm.cpp
diff --git a/src/routines/level3/xhemm.cc b/src/routines/level3/xhemm.cpp
index 9813503e..9813503e 100644
--- a/src/routines/level3/xhemm.cc
+++ b/src/routines/level3/xhemm.cpp
diff --git a/src/routines/level3/xher2k.cc b/src/routines/level3/xher2k.cpp
index bd7a053e..bd7a053e 100644
--- a/src/routines/level3/xher2k.cc
+++ b/src/routines/level3/xher2k.cpp
diff --git a/src/routines/level3/xherk.cc b/src/routines/level3/xherk.cpp
index 6ef7f21f..6ef7f21f 100644
--- a/src/routines/level3/xherk.cc
+++ b/src/routines/level3/xherk.cpp
diff --git a/src/routines/level3/xsymm.cc b/src/routines/level3/xsymm.cpp
index 04e4b718..04e4b718 100644
--- a/src/routines/level3/xsymm.cc
+++ b/src/routines/level3/xsymm.cpp
diff --git a/src/routines/level3/xsyr2k.cc b/src/routines/level3/xsyr2k.cpp
index 424d4d2d..424d4d2d 100644
--- a/src/routines/level3/xsyr2k.cc
+++ b/src/routines/level3/xsyr2k.cpp
diff --git a/src/routines/level3/xsyrk.cc b/src/routines/level3/xsyrk.cpp
index f56c232b..f56c232b 100644
--- a/src/routines/level3/xsyrk.cc
+++ b/src/routines/level3/xsyrk.cpp
diff --git a/src/routines/level3/xtrmm.cc b/src/routines/level3/xtrmm.cpp
index 74a82822..74a82822 100644
--- a/src/routines/level3/xtrmm.cc
+++ b/src/routines/level3/xtrmm.cpp
diff --git a/src/routines/levelx/xomatcopy.cc b/src/routines/levelx/xomatcopy.cpp
index e8593301..e8593301 100644
--- a/src/routines/levelx/xomatcopy.cc
+++ b/src/routines/levelx/xomatcopy.cpp
diff --git a/src/tuning/kernels/copy_fast.cc b/src/tuning/kernels/copy_fast.cpp
index 34269bc7..34269bc7 100644
--- a/src/tuning/kernels/copy_fast.cc
+++ b/src/tuning/kernels/copy_fast.cpp
diff --git a/src/tuning/kernels/copy_pad.cc b/src/tuning/kernels/copy_pad.cpp
index 1e0dccd3..1e0dccd3 100644
--- a/src/tuning/kernels/copy_pad.cc
+++ b/src/tuning/kernels/copy_pad.cpp
diff --git a/src/tuning/kernels/transpose_fast.cc b/src/tuning/kernels/transpose_fast.cpp
index 7ac19cb6..7ac19cb6 100644
--- a/src/tuning/kernels/transpose_fast.cc
+++ b/src/tuning/kernels/transpose_fast.cpp
diff --git a/src/tuning/kernels/transpose_pad.cc b/src/tuning/kernels/transpose_pad.cpp
index 63274415..63274415 100644
--- a/src/tuning/kernels/transpose_pad.cc
+++ b/src/tuning/kernels/transpose_pad.cpp
diff --git a/src/tuning/kernels/xaxpy.cc b/src/tuning/kernels/xaxpy.cpp
index 88d12c1f..88d12c1f 100644
--- a/src/tuning/kernels/xaxpy.cc
+++ b/src/tuning/kernels/xaxpy.cpp
diff --git a/src/tuning/kernels/xdot.cc b/src/tuning/kernels/xdot.cpp
index 1581e13f..1581e13f 100644
--- a/src/tuning/kernels/xdot.cc
+++ b/src/tuning/kernels/xdot.cpp
diff --git a/src/tuning/kernels/xgemm.cc b/src/tuning/kernels/xgemm.cpp
index 4b1efdef..4b1efdef 100644
--- a/src/tuning/kernels/xgemm.cc
+++ b/src/tuning/kernels/xgemm.cpp
diff --git a/src/tuning/kernels/xgemv.cc b/src/tuning/kernels/xgemv.cpp
index d42155ae..d42155ae 100644
--- a/src/tuning/kernels/xgemv.cc
+++ b/src/tuning/kernels/xgemv.cpp
diff --git a/src/tuning/kernels/xger.cc b/src/tuning/kernels/xger.cpp
index d2590c53..d2590c53 100644
--- a/src/tuning/kernels/xger.cc
+++ b/src/tuning/kernels/xger.cpp
diff --git a/src/utilities.cc b/src/utilities.cpp
index e3a1fb75..e3a1fb75 100644
--- a/src/utilities.cc
+++ b/src/utilities.cpp
diff --git a/test/correctness/routines/level1/xamax.cc b/test/correctness/routines/level1/xamax.cpp
index 607637e8..607637e8 100644
--- a/test/correctness/routines/level1/xamax.cc
+++ b/test/correctness/routines/level1/xamax.cpp
diff --git a/test/correctness/routines/level1/xasum.cc b/test/correctness/routines/level1/xasum.cpp
index e22e42a6..e22e42a6 100644
--- a/test/correctness/routines/level1/xasum.cc
+++ b/test/correctness/routines/level1/xasum.cpp
diff --git a/test/correctness/routines/level1/xaxpy.cc b/test/correctness/routines/level1/xaxpy.cpp
index 064172fa..064172fa 100644
--- a/test/correctness/routines/level1/xaxpy.cc
+++ b/test/correctness/routines/level1/xaxpy.cpp
diff --git a/test/correctness/routines/level1/xcopy.cc b/test/correctness/routines/level1/xcopy.cpp
index e6f2581b..e6f2581b 100644
--- a/test/correctness/routines/level1/xcopy.cc
+++ b/test/correctness/routines/level1/xcopy.cpp
diff --git a/test/correctness/routines/level1/xdot.cc b/test/correctness/routines/level1/xdot.cpp
index 080250cb..080250cb 100644
--- a/test/correctness/routines/level1/xdot.cc
+++ b/test/correctness/routines/level1/xdot.cpp
diff --git a/test/correctness/routines/level1/xdotc.cc b/test/correctness/routines/level1/xdotc.cpp
index 2a7bbeca..2a7bbeca 100644
--- a/test/correctness/routines/level1/xdotc.cc
+++ b/test/correctness/routines/level1/xdotc.cpp
diff --git a/test/correctness/routines/level1/xdotu.cc b/test/correctness/routines/level1/xdotu.cpp
index 1047d021..1047d021 100644
--- a/test/correctness/routines/level1/xdotu.cc
+++ b/test/correctness/routines/level1/xdotu.cpp
diff --git a/test/correctness/routines/level1/xnrm2.cc b/test/correctness/routines/level1/xnrm2.cpp
index 142fa7ba..142fa7ba 100644
--- a/test/correctness/routines/level1/xnrm2.cc
+++ b/test/correctness/routines/level1/xnrm2.cpp
diff --git a/test/correctness/routines/level1/xrot.cc b/test/correctness/routines/level1/xrot.cpp
index 5af358eb..5af358eb 100644
--- a/test/correctness/routines/level1/xrot.cc
+++ b/test/correctness/routines/level1/xrot.cpp
diff --git a/test/correctness/routines/level1/xrotg.cc b/test/correctness/routines/level1/xrotg.cpp
index ad23a554..ad23a554 100644
--- a/test/correctness/routines/level1/xrotg.cc
+++ b/test/correctness/routines/level1/xrotg.cpp
diff --git a/test/correctness/routines/level1/xrotm.cc b/test/correctness/routines/level1/xrotm.cpp
index 4f7e8f15..4f7e8f15 100644
--- a/test/correctness/routines/level1/xrotm.cc
+++ b/test/correctness/routines/level1/xrotm.cpp
diff --git a/test/correctness/routines/level1/xrotmg.cc b/test/correctness/routines/level1/xrotmg.cpp
index ca89bc12..ca89bc12 100644
--- a/test/correctness/routines/level1/xrotmg.cc
+++ b/test/correctness/routines/level1/xrotmg.cpp
diff --git a/test/correctness/routines/level1/xscal.cc b/test/correctness/routines/level1/xscal.cpp
index 939524be..939524be 100644
--- a/test/correctness/routines/level1/xscal.cc
+++ b/test/correctness/routines/level1/xscal.cpp
diff --git a/test/correctness/routines/level1/xswap.cc b/test/correctness/routines/level1/xswap.cpp
index 446f3d65..446f3d65 100644
--- a/test/correctness/routines/level1/xswap.cc
+++ b/test/correctness/routines/level1/xswap.cpp
diff --git a/test/correctness/routines/level2/xgbmv.cc b/test/correctness/routines/level2/xgbmv.cpp
index 8c49bc65..8c49bc65 100644
--- a/test/correctness/routines/level2/xgbmv.cc
+++ b/test/correctness/routines/level2/xgbmv.cpp
diff --git a/test/correctness/routines/level2/xgemv.cc b/test/correctness/routines/level2/xgemv.cpp
index 902ae777..902ae777 100644
--- a/test/correctness/routines/level2/xgemv.cc
+++ b/test/correctness/routines/level2/xgemv.cpp
diff --git a/test/correctness/routines/level2/xger.cc b/test/correctness/routines/level2/xger.cpp
index ce61bbcb..ce61bbcb 100644
--- a/test/correctness/routines/level2/xger.cc
+++ b/test/correctness/routines/level2/xger.cpp
diff --git a/test/correctness/routines/level2/xgerc.cc b/test/correctness/routines/level2/xgerc.cpp
index b747f20d..b747f20d 100644
--- a/test/correctness/routines/level2/xgerc.cc
+++ b/test/correctness/routines/level2/xgerc.cpp
diff --git a/test/correctness/routines/level2/xgeru.cc b/test/correctness/routines/level2/xgeru.cpp
index f80c1e2b..f80c1e2b 100644
--- a/test/correctness/routines/level2/xgeru.cc
+++ b/test/correctness/routines/level2/xgeru.cpp
diff --git a/test/correctness/routines/level2/xhbmv.cc b/test/correctness/routines/level2/xhbmv.cpp
index a4885c01..a4885c01 100644
--- a/test/correctness/routines/level2/xhbmv.cc
+++ b/test/correctness/routines/level2/xhbmv.cpp
diff --git a/test/correctness/routines/level2/xhemv.cc b/test/correctness/routines/level2/xhemv.cpp
index 4318ffee..4318ffee 100644
--- a/test/correctness/routines/level2/xhemv.cc
+++ b/test/correctness/routines/level2/xhemv.cpp
diff --git a/test/correctness/routines/level2/xher.cc b/test/correctness/routines/level2/xher.cpp
index fe37bd76..fe37bd76 100644
--- a/test/correctness/routines/level2/xher.cc
+++ b/test/correctness/routines/level2/xher.cpp
diff --git a/test/correctness/routines/level2/xher2.cc b/test/correctness/routines/level2/xher2.cpp
index 0b4af4d0..0b4af4d0 100644
--- a/test/correctness/routines/level2/xher2.cc
+++ b/test/correctness/routines/level2/xher2.cpp
diff --git a/test/correctness/routines/level2/xhpmv.cc b/test/correctness/routines/level2/xhpmv.cpp
index dd77df71..dd77df71 100644
--- a/test/correctness/routines/level2/xhpmv.cc
+++ b/test/correctness/routines/level2/xhpmv.cpp
diff --git a/test/correctness/routines/level2/xhpr.cc b/test/correctness/routines/level2/xhpr.cpp
index 5a3f615f..5a3f615f 100644
--- a/test/correctness/routines/level2/xhpr.cc
+++ b/test/correctness/routines/level2/xhpr.cpp
diff --git a/test/correctness/routines/level2/xhpr2.cc b/test/correctness/routines/level2/xhpr2.cpp
index 8218b444..8218b444 100644
--- a/test/correctness/routines/level2/xhpr2.cc
+++ b/test/correctness/routines/level2/xhpr2.cpp
diff --git a/test/correctness/routines/level2/xsbmv.cc b/test/correctness/routines/level2/xsbmv.cpp
index 7918cb21..7918cb21 100644
--- a/test/correctness/routines/level2/xsbmv.cc
+++ b/test/correctness/routines/level2/xsbmv.cpp
diff --git a/test/correctness/routines/level2/xspmv.cc b/test/correctness/routines/level2/xspmv.cpp
index 78210660..78210660 100644
--- a/test/correctness/routines/level2/xspmv.cc
+++ b/test/correctness/routines/level2/xspmv.cpp
diff --git a/test/correctness/routines/level2/xspr.cc b/test/correctness/routines/level2/xspr.cpp
index d05adf34..d05adf34 100644
--- a/test/correctness/routines/level2/xspr.cc
+++ b/test/correctness/routines/level2/xspr.cpp
diff --git a/test/correctness/routines/level2/xspr2.cc b/test/correctness/routines/level2/xspr2.cpp
index caa46a09..caa46a09 100644
--- a/test/correctness/routines/level2/xspr2.cc
+++ b/test/correctness/routines/level2/xspr2.cpp
diff --git a/test/correctness/routines/level2/xsymv.cc b/test/correctness/routines/level2/xsymv.cpp
index 978a5f8a..978a5f8a 100644
--- a/test/correctness/routines/level2/xsymv.cc
+++ b/test/correctness/routines/level2/xsymv.cpp
diff --git a/test/correctness/routines/level2/xsyr.cc b/test/correctness/routines/level2/xsyr.cpp
index 244dbfb4..244dbfb4 100644
--- a/test/correctness/routines/level2/xsyr.cc
+++ b/test/correctness/routines/level2/xsyr.cpp
diff --git a/test/correctness/routines/level2/xsyr2.cc b/test/correctness/routines/level2/xsyr2.cpp
index 422e67ad..422e67ad 100644
--- a/test/correctness/routines/level2/xsyr2.cc
+++ b/test/correctness/routines/level2/xsyr2.cpp
diff --git a/test/correctness/routines/level2/xtbmv.cc b/test/correctness/routines/level2/xtbmv.cpp
index 491708ec..491708ec 100644
--- a/test/correctness/routines/level2/xtbmv.cc
+++ b/test/correctness/routines/level2/xtbmv.cpp
diff --git a/test/correctness/routines/level2/xtbsv.cc b/test/correctness/routines/level2/xtbsv.cpp
index 12b5dca5..12b5dca5 100644
--- a/test/correctness/routines/level2/xtbsv.cc
+++ b/test/correctness/routines/level2/xtbsv.cpp
diff --git a/test/correctness/routines/level2/xtpmv.cc b/test/correctness/routines/level2/xtpmv.cpp
index b89f0adc..b89f0adc 100644
--- a/test/correctness/routines/level2/xtpmv.cc
+++ b/test/correctness/routines/level2/xtpmv.cpp
diff --git a/test/correctness/routines/level2/xtpsv.cc b/test/correctness/routines/level2/xtpsv.cpp
index 6e6e7c85..6e6e7c85 100644
--- a/test/correctness/routines/level2/xtpsv.cc
+++ b/test/correctness/routines/level2/xtpsv.cpp
diff --git a/test/correctness/routines/level2/xtrmv.cc b/test/correctness/routines/level2/xtrmv.cpp
index 819f5cad..819f5cad 100644
--- a/test/correctness/routines/level2/xtrmv.cc
+++ b/test/correctness/routines/level2/xtrmv.cpp
diff --git a/test/correctness/routines/level2/xtrsv.cc b/test/correctness/routines/level2/xtrsv.cpp
index 78e33807..78e33807 100644
--- a/test/correctness/routines/level2/xtrsv.cc
+++ b/test/correctness/routines/level2/xtrsv.cpp
diff --git a/test/correctness/routines/level3/xgemm.cc b/test/correctness/routines/level3/xgemm.cpp
index 54d41719..54d41719 100644
--- a/test/correctness/routines/level3/xgemm.cc
+++ b/test/correctness/routines/level3/xgemm.cpp
diff --git a/test/correctness/routines/level3/xhemm.cc b/test/correctness/routines/level3/xhemm.cpp
index 76c970a7..76c970a7 100644
--- a/test/correctness/routines/level3/xhemm.cc
+++ b/test/correctness/routines/level3/xhemm.cpp
diff --git a/test/correctness/routines/level3/xher2k.cc b/test/correctness/routines/level3/xher2k.cpp
index c653265e..c653265e 100644
--- a/test/correctness/routines/level3/xher2k.cc
+++ b/test/correctness/routines/level3/xher2k.cpp
diff --git a/test/correctness/routines/level3/xherk.cc b/test/correctness/routines/level3/xherk.cpp
index 09ea9e4d..09ea9e4d 100644
--- a/test/correctness/routines/level3/xherk.cc
+++ b/test/correctness/routines/level3/xherk.cpp
diff --git a/test/correctness/routines/level3/xsymm.cc b/test/correctness/routines/level3/xsymm.cpp
index 3cb3515a..3cb3515a 100644
--- a/test/correctness/routines/level3/xsymm.cc
+++ b/test/correctness/routines/level3/xsymm.cpp
diff --git a/test/correctness/routines/level3/xsyr2k.cc b/test/correctness/routines/level3/xsyr2k.cpp
index 617af04d..617af04d 100644
--- a/test/correctness/routines/level3/xsyr2k.cc
+++ b/test/correctness/routines/level3/xsyr2k.cpp
diff --git a/test/correctness/routines/level3/xsyrk.cc b/test/correctness/routines/level3/xsyrk.cpp
index 2014b8d0..2014b8d0 100644
--- a/test/correctness/routines/level3/xsyrk.cc
+++ b/test/correctness/routines/level3/xsyrk.cpp
diff --git a/test/correctness/routines/level3/xtrmm.cc b/test/correctness/routines/level3/xtrmm.cpp
index 32640d52..32640d52 100644
--- a/test/correctness/routines/level3/xtrmm.cc
+++ b/test/correctness/routines/level3/xtrmm.cpp
diff --git a/test/correctness/routines/level3/xtrsm.cc b/test/correctness/routines/level3/xtrsm.cpp
index 6119bd17..6119bd17 100644
--- a/test/correctness/routines/level3/xtrsm.cc
+++ b/test/correctness/routines/level3/xtrsm.cpp
diff --git a/test/correctness/routines/levelx/xomatcopy.cc b/test/correctness/routines/levelx/xomatcopy.cpp
index e034bc18..e034bc18 100644
--- a/test/correctness/routines/levelx/xomatcopy.cc
+++ b/test/correctness/routines/levelx/xomatcopy.cpp
diff --git a/test/correctness/testblas.cc b/test/correctness/testblas.cpp
index cec8bafa..cec8bafa 100644
--- a/test/correctness/testblas.cc
+++ b/test/correctness/testblas.cpp
diff --git a/test/correctness/tester.cc b/test/correctness/tester.cpp
index 92e2c1b8..92e2c1b8 100644
--- a/test/correctness/tester.cc
+++ b/test/correctness/tester.cpp
diff --git a/test/performance/client.cc b/test/performance/client.cpp
index d0068f8b..d0068f8b 100644
--- a/test/performance/client.cc
+++ b/test/performance/client.cpp
diff --git a/test/performance/routines/level1/xamax.cc b/test/performance/routines/level1/xamax.cpp
index 450678e0..450678e0 100644
--- a/test/performance/routines/level1/xamax.cc
+++ b/test/performance/routines/level1/xamax.cpp
diff --git a/test/performance/routines/level1/xasum.cc b/test/performance/routines/level1/xasum.cpp
index c21102f5..c21102f5 100644
--- a/test/performance/routines/level1/xasum.cc
+++ b/test/performance/routines/level1/xasum.cpp
diff --git a/test/performance/routines/level1/xaxpy.cc b/test/performance/routines/level1/xaxpy.cpp
index e1c4935e..e1c4935e 100644
--- a/test/performance/routines/level1/xaxpy.cc
+++ b/test/performance/routines/level1/xaxpy.cpp
diff --git a/test/performance/routines/level1/xcopy.cc b/test/performance/routines/level1/xcopy.cpp
index ea3531a0..ea3531a0 100644
--- a/test/performance/routines/level1/xcopy.cc
+++ b/test/performance/routines/level1/xcopy.cpp
diff --git a/test/performance/routines/level1/xdot.cc b/test/performance/routines/level1/xdot.cpp
index 09fe9258..09fe9258 100644
--- a/test/performance/routines/level1/xdot.cc
+++ b/test/performance/routines/level1/xdot.cpp
diff --git a/test/performance/routines/level1/xdotc.cc b/test/performance/routines/level1/xdotc.cpp
index 6e716ebb..6e716ebb 100644
--- a/test/performance/routines/level1/xdotc.cc
+++ b/test/performance/routines/level1/xdotc.cpp
diff --git a/test/performance/routines/level1/xdotu.cc b/test/performance/routines/level1/xdotu.cpp
index d011d558..d011d558 100644
--- a/test/performance/routines/level1/xdotu.cc
+++ b/test/performance/routines/level1/xdotu.cpp
diff --git a/test/performance/routines/level1/xnrm2.cc b/test/performance/routines/level1/xnrm2.cpp
index 1d6e177d..1d6e177d 100644
--- a/test/performance/routines/level1/xnrm2.cc
+++ b/test/performance/routines/level1/xnrm2.cpp
diff --git a/test/performance/routines/level1/xrot.cc b/test/performance/routines/level1/xrot.cpp
index 4b543f1b..4b543f1b 100644
--- a/test/performance/routines/level1/xrot.cc
+++ b/test/performance/routines/level1/xrot.cpp
diff --git a/test/performance/routines/level1/xrotg.cc b/test/performance/routines/level1/xrotg.cpp
index e52704b0..e52704b0 100644
--- a/test/performance/routines/level1/xrotg.cc
+++ b/test/performance/routines/level1/xrotg.cpp
diff --git a/test/performance/routines/level1/xrotm.cc b/test/performance/routines/level1/xrotm.cpp
index 83ee1d9d..83ee1d9d 100644
--- a/test/performance/routines/level1/xrotm.cc
+++ b/test/performance/routines/level1/xrotm.cpp
diff --git a/test/performance/routines/level1/xrotmg.cc b/test/performance/routines/level1/xrotmg.cpp
index ee1539d9..ee1539d9 100644
--- a/test/performance/routines/level1/xrotmg.cc
+++ b/test/performance/routines/level1/xrotmg.cpp
diff --git a/test/performance/routines/level1/xscal.cc b/test/performance/routines/level1/xscal.cpp
index adb83a90..adb83a90 100644
--- a/test/performance/routines/level1/xscal.cc
+++ b/test/performance/routines/level1/xscal.cpp
diff --git a/test/performance/routines/level1/xswap.cc b/test/performance/routines/level1/xswap.cpp
index 7f591d19..7f591d19 100644
--- a/test/performance/routines/level1/xswap.cc
+++ b/test/performance/routines/level1/xswap.cpp
diff --git a/test/performance/routines/level2/xgbmv.cc b/test/performance/routines/level2/xgbmv.cpp
index 6aa72ded..6aa72ded 100644
--- a/test/performance/routines/level2/xgbmv.cc
+++ b/test/performance/routines/level2/xgbmv.cpp
diff --git a/test/performance/routines/level2/xgemv.cc b/test/performance/routines/level2/xgemv.cpp
index fdcef95d..fdcef95d 100644
--- a/test/performance/routines/level2/xgemv.cc
+++ b/test/performance/routines/level2/xgemv.cpp
diff --git a/test/performance/routines/level2/xger.cc b/test/performance/routines/level2/xger.cpp
index c4f3699d..c4f3699d 100644
--- a/test/performance/routines/level2/xger.cc
+++ b/test/performance/routines/level2/xger.cpp
diff --git a/test/performance/routines/level2/xgerc.cc b/test/performance/routines/level2/xgerc.cpp
index f855dc11..f855dc11 100644
--- a/test/performance/routines/level2/xgerc.cc
+++ b/test/performance/routines/level2/xgerc.cpp
diff --git a/test/performance/routines/level2/xgeru.cc b/test/performance/routines/level2/xgeru.cpp
index 2bf885e3..2bf885e3 100644
--- a/test/performance/routines/level2/xgeru.cc
+++ b/test/performance/routines/level2/xgeru.cpp
diff --git a/test/performance/routines/level2/xhbmv.cc b/test/performance/routines/level2/xhbmv.cpp
index b7f3b9ad..b7f3b9ad 100644
--- a/test/performance/routines/level2/xhbmv.cc
+++ b/test/performance/routines/level2/xhbmv.cpp
diff --git a/test/performance/routines/level2/xhemv.cc b/test/performance/routines/level2/xhemv.cpp
index e1168083..e1168083 100644
--- a/test/performance/routines/level2/xhemv.cc
+++ b/test/performance/routines/level2/xhemv.cpp
diff --git a/test/performance/routines/level2/xher.cc b/test/performance/routines/level2/xher.cpp
index 0d1bc1dd..0d1bc1dd 100644
--- a/test/performance/routines/level2/xher.cc
+++ b/test/performance/routines/level2/xher.cpp
diff --git a/test/performance/routines/level2/xher2.cc b/test/performance/routines/level2/xher2.cpp
index 3d98c838..3d98c838 100644
--- a/test/performance/routines/level2/xher2.cc
+++ b/test/performance/routines/level2/xher2.cpp
diff --git a/test/performance/routines/level2/xhpmv.cc b/test/performance/routines/level2/xhpmv.cpp
index c3bc3d9c..c3bc3d9c 100644
--- a/test/performance/routines/level2/xhpmv.cc
+++ b/test/performance/routines/level2/xhpmv.cpp
diff --git a/test/performance/routines/level2/xhpr.cc b/test/performance/routines/level2/xhpr.cpp
index afc65b25..afc65b25 100644
--- a/test/performance/routines/level2/xhpr.cc
+++ b/test/performance/routines/level2/xhpr.cpp
diff --git a/test/performance/routines/level2/xhpr2.cc b/test/performance/routines/level2/xhpr2.cpp
index c543dc90..c543dc90 100644
--- a/test/performance/routines/level2/xhpr2.cc
+++ b/test/performance/routines/level2/xhpr2.cpp
diff --git a/test/performance/routines/level2/xsbmv.cc b/test/performance/routines/level2/xsbmv.cpp
index 32899a74..32899a74 100644
--- a/test/performance/routines/level2/xsbmv.cc
+++ b/test/performance/routines/level2/xsbmv.cpp
diff --git a/test/performance/routines/level2/xspmv.cc b/test/performance/routines/level2/xspmv.cpp
index 0b0d2409..0b0d2409 100644
--- a/test/performance/routines/level2/xspmv.cc
+++ b/test/performance/routines/level2/xspmv.cpp
diff --git a/test/performance/routines/level2/xspr.cc b/test/performance/routines/level2/xspr.cpp
index 9c1c80a0..9c1c80a0 100644
--- a/test/performance/routines/level2/xspr.cc
+++ b/test/performance/routines/level2/xspr.cpp
diff --git a/test/performance/routines/level2/xspr2.cc b/test/performance/routines/level2/xspr2.cpp
index 117e9c2f..117e9c2f 100644
--- a/test/performance/routines/level2/xspr2.cc
+++ b/test/performance/routines/level2/xspr2.cpp
diff --git a/test/performance/routines/level2/xsymv.cc b/test/performance/routines/level2/xsymv.cpp
index 60db1ae9..60db1ae9 100644
--- a/test/performance/routines/level2/xsymv.cc
+++ b/test/performance/routines/level2/xsymv.cpp
diff --git a/test/performance/routines/level2/xsyr.cc b/test/performance/routines/level2/xsyr.cpp
index d9ecd38a..d9ecd38a 100644
--- a/test/performance/routines/level2/xsyr.cc
+++ b/test/performance/routines/level2/xsyr.cpp
diff --git a/test/performance/routines/level2/xsyr2.cc b/test/performance/routines/level2/xsyr2.cpp
index 24e0a517..24e0a517 100644
--- a/test/performance/routines/level2/xsyr2.cc
+++ b/test/performance/routines/level2/xsyr2.cpp
diff --git a/test/performance/routines/level2/xtbmv.cc b/test/performance/routines/level2/xtbmv.cpp
index ed9d26a8..ed9d26a8 100644
--- a/test/performance/routines/level2/xtbmv.cc
+++ b/test/performance/routines/level2/xtbmv.cpp
diff --git a/test/performance/routines/level2/xtbsv.cc b/test/performance/routines/level2/xtbsv.cpp
index f0b80330..f0b80330 100644
--- a/test/performance/routines/level2/xtbsv.cc
+++ b/test/performance/routines/level2/xtbsv.cpp
diff --git a/test/performance/routines/level2/xtpmv.cc b/test/performance/routines/level2/xtpmv.cpp
index c5801205..c5801205 100644
--- a/test/performance/routines/level2/xtpmv.cc
+++ b/test/performance/routines/level2/xtpmv.cpp
diff --git a/test/performance/routines/level2/xtpsv.cc b/test/performance/routines/level2/xtpsv.cpp
index db956c9d..db956c9d 100644
--- a/test/performance/routines/level2/xtpsv.cc
+++ b/test/performance/routines/level2/xtpsv.cpp
diff --git a/test/performance/routines/level2/xtrmv.cc b/test/performance/routines/level2/xtrmv.cpp
index 629c773c..629c773c 100644
--- a/test/performance/routines/level2/xtrmv.cc
+++ b/test/performance/routines/level2/xtrmv.cpp
diff --git a/test/performance/routines/level2/xtrsv.cc b/test/performance/routines/level2/xtrsv.cpp
index d6c2968c..d6c2968c 100644
--- a/test/performance/routines/level2/xtrsv.cc
+++ b/test/performance/routines/level2/xtrsv.cpp
diff --git a/test/performance/routines/level3/xgemm.cc b/test/performance/routines/level3/xgemm.cpp
index 3f68096e..3f68096e 100644
--- a/test/performance/routines/level3/xgemm.cc
+++ b/test/performance/routines/level3/xgemm.cpp
diff --git a/test/performance/routines/level3/xhemm.cc b/test/performance/routines/level3/xhemm.cpp
index ff6d0f71..ff6d0f71 100644
--- a/test/performance/routines/level3/xhemm.cc
+++ b/test/performance/routines/level3/xhemm.cpp
diff --git a/test/performance/routines/level3/xher2k.cc b/test/performance/routines/level3/xher2k.cpp
index 9636959e..9636959e 100644
--- a/test/performance/routines/level3/xher2k.cc
+++ b/test/performance/routines/level3/xher2k.cpp
diff --git a/test/performance/routines/level3/xherk.cc b/test/performance/routines/level3/xherk.cpp
index d51400f0..d51400f0 100644
--- a/test/performance/routines/level3/xherk.cc
+++ b/test/performance/routines/level3/xherk.cpp
diff --git a/test/performance/routines/level3/xsymm.cc b/test/performance/routines/level3/xsymm.cpp
index 38c3dc9b..38c3dc9b 100644
--- a/test/performance/routines/level3/xsymm.cc
+++ b/test/performance/routines/level3/xsymm.cpp
diff --git a/test/performance/routines/level3/xsyr2k.cc b/test/performance/routines/level3/xsyr2k.cpp
index 5360e297..5360e297 100644
--- a/test/performance/routines/level3/xsyr2k.cc
+++ b/test/performance/routines/level3/xsyr2k.cpp
diff --git a/test/performance/routines/level3/xsyrk.cc b/test/performance/routines/level3/xsyrk.cpp
index 30612f99..30612f99 100644
--- a/test/performance/routines/level3/xsyrk.cc
+++ b/test/performance/routines/level3/xsyrk.cpp
diff --git a/test/performance/routines/level3/xtrmm.cc b/test/performance/routines/level3/xtrmm.cpp
index 264a34e7..264a34e7 100644
--- a/test/performance/routines/level3/xtrmm.cc
+++ b/test/performance/routines/level3/xtrmm.cpp
diff --git a/test/performance/routines/level3/xtrsm.cc b/test/performance/routines/level3/xtrsm.cpp
index 80c46d91..80c46d91 100644
--- a/test/performance/routines/level3/xtrsm.cc
+++ b/test/performance/routines/level3/xtrsm.cpp
diff --git a/test/performance/routines/levelx/xomatcopy.cc b/test/performance/routines/levelx/xomatcopy.cpp
index 0bd5773e..0bd5773e 100644
--- a/test/performance/routines/levelx/xomatcopy.cc
+++ b/test/performance/routines/levelx/xomatcopy.cpp
diff --git a/scripts/generator/generator.py b/scripts/generator/generator.py
index 1df4c8e6..cf01f79e 100644
--- a/scripts/generator/generator.py
+++ b/scripts/generator/generator.py
@@ -10,14 +10,14 @@
# This script automatically generates the bodies of the following files, creating the full CLBlast
# API interface and implementation (C, C++, and reference BLAS wrappers):
# clblast.h
-# clblast.cc
+# clblast.cpp
# clblast_c.h
-# clblast_c.cc
+# clblast_c.cpp
# wrapper_clblas.h
# wrapper_cblas.h
# It also generates the main functions for the correctness and performance tests as found in
-# test/correctness/routines/levelX/xYYYY.cc
-# test/performance/routines/levelX/xYYYY.cc
+# test/correctness/routines/levelX/xYYYY.cpp
+# test/performance/routines/levelX/xYYYY.cpp
# It also produces the API documentation found in doc/clblast.md
#
# ==================================================================================================
@@ -200,7 +200,7 @@ def clblast_h(routines):
result += routine.RoutineHeaderCPP(12, " = nullptr")+";\n"
return result
# The C++ API implementation (.cc)
def clblast_cc(routines):
result = ""
for routine in routines:
@@ -237,7 +237,7 @@ def clblast_c_h(routines):
result += routine.RoutineHeaderC(flavour, 31, " PUBLIC_API")+";\n"
return result
# The C API implementation (.cc)
def clblast_c_cc(routines):
result = ""
for routine in routines:
@@ -379,9 +379,9 @@ if len(sys.argv) != 2:
path_clblast = sys.argv[1]
files = [
path_clblast+"/include/clblast.h",
- path_clblast+"/src/clblast.cc",
+ path_clblast+"/src/clblast.cpp",
path_clblast+"/include/clblast_c.h",
- path_clblast+"/src/clblast_c.cc",
+ path_clblast+"/src/clblast_c.cpp",
path_clblast+"/test/wrapper_clblas.hpp",
path_clblast+"/test/wrapper_cblas.hpp",
]
@@ -433,7 +433,7 @@ for i in xrange(0,len(files)):
for level in [1,2,3,4]:
for routine in routines[level-1]:
if routine.has_tests:
- filename = path_clblast+"/test/correctness/routines/level"+levelnames[level-1]+"/x"+routine.name+".cc"
+ filename = path_clblast+"/test/correctness/routines/level"+levelnames[level-1]+"/x"+routine.name+".cpp"
with open(filename, "w") as f:
body = ""
body += "#include \"test/correctness/testblas.hpp\"\n"
@@ -459,7 +459,7 @@ for level in [1,2,3,4]:
for level in [1,2,3,4]:
for routine in routines[level-1]:
if routine.has_tests:
- filename = path_clblast+"/test/performance/routines/level"+levelnames[level-1]+"/x"+routine.name+".cc"
+ filename = path_clblast+"/test/performance/routines/level"+levelnames[level-1]+"/x"+routine.name+".cpp"
with open(filename, "w") as f:
body = ""
body += "#include \"test/performance/client.hpp\"\n"
@@ -200,7 +200,7 @@ def clblast_h(routines):
result += routine.RoutineHeaderCPP(12, " = nullptr")+";\n"
return result
-# The C++ API implementation (.cc)
+# The C++ API implementation (.cpp)
def clblast_cc(routines):
result = ""
@@ -237,7 +237,7 @@ def clblast_c_h(routines):
result += routine.RoutineHeaderC(flavour, 31, " PUBLIC_API")+";\n"
return result
-# The C API implementation (.cc)
+# The C API implementation (.cpp)
def clblast_c_cc(routines):
result = ""